class MoneyDt
    # amount: Rational, currency: String
    attr_reader :amount, :currency

    # Example:
    #   >> fifty_eur = MoneyDt.new(50, "EUR") #=> <MoneyDt amount:50/1 currency:EUR>
    #
    # Arguments:
    #   amount: Fixnum, Float
    #   currency: String
    #
    def initialize(amount, currency)
        # The conversion to String is necessary as for a Float it isn't always valid to directly convert to Rational
        @amount = amount.to_s.to_r
        @currency = currency
    end

    # Example:
    #   >> fifty_eur = MoneyDt.new(50, "EUR")
    #   >> fifty_eur.inspect #=> "50.00 EUR"
    #
    def inspect
        "#{'%.2f' % amount} #{currency}"
    end

    require "money_dt/conversions"
    require "money_dt/arithmetics"
    require "money_dt/comparisons"
end
