class MoneyDt
    @@conversion_rates = {}

    # Example:
    #   >> MoneyDt.conversion_rates("EUR", { "USD" => 1.11, "Bitcoin" => 0.0047 })
    #
    # Arguments:
    #   base_currency: String
    #   rates: Hash
    #
    def self.conversion_rates(base_currency, rates)
        @@conversion_rates[base_currency] ||= {}
        @@conversion_rates[base_currency].merge!(rates)
    end

    # Example:
    #   >> MoneyDt.conversion_rates("EUR", { "USD" => 1.11, "Bitcoin" => 0.0047 })
    #   >> fifty_eur = MoneyDt.new(50, "EUR")
    #   >> fifty_eur.convert_to("USD") #=> <MoneyDt amount:555/10, currency:USD>
    #
    # Arguments:
    #   new_currency: String
    #
    def convert_to(new_currency)
        if @@conversion_rates[self.currency] && (rate = @@conversion_rates[self.currency][new_currency])
            # When converting to a base currency (rates are based on it)
            MoneyDt.new(self.amount * rate, new_currency)
        elsif @@conversion_rates[new_currency] && (rate = @@conversion_rates[new_currency][self.currency])
            # When converting to another currency (rates aren't based on it)
            MoneyDt.new(self.amount * (1 / rate), new_currency)
        end
    end
end
